@@ -5,8 +5,8 @@ use base 'PDF::Builder::Resource::CIDFont';
 use strict;
 use warnings;
 
-our $VERSION = '3.025'; # VERSION
-our $LAST_UPDATE = '3.024'; # manually update whenever code is changed
+our $VERSION = '3.028'; # VERSION
+our $LAST_UPDATE = '3.028'; # manually update whenever code is changed
 
 use PDF::Builder::Util;
 use PDF::Builder::Basic::PDF::Utils;
@@ -20,31 +20,56 @@ our $subs;
 
 PDF::Builder::Resource::CIDFont::CJKFont - Base class for CJK fonts
 
+Inherits from L<PDF::Builder::Resource::CIDFont>
+
+B<Note:> CJK font support is somewhat obsolete. Try directly using an
+up-to-date TTF or OTF font, with UTF-8 input, instead.
+
 =head1 METHODS
 
-=over
+=head2 new
 
-=item $font = PDF::Builder::Resource::CIDFont::CJKFont->new($pdf, $cjkname, %options)
+    $font = PDF::Builder::Resource::CIDFont::CJKFont->new($pdf, $cjkname, %opts)
+
+=over
 
 Returns a cjk-font object.
 
+=back
+
 =over
 
-* Traditional Chinese: Ming Ming-Bold Ming-Italic Ming-BoldItalic
+=item * 
 
-* Simplified Chinese: Song Song-Bold Song-Italic Song-BoldItalic
+B<Traditional Chinese:> Ming, Ming-Bold, Ming-Italic, Ming-BoldItalic
 
-* Korean: MyungJo MyungJo-Bold MyungJo-Italic MyungJo-BoldItalic
+=item * 
 
-* Japanese (Mincho): KozMin KozMin-Bold KozMin-Italic KozMin-BoldItalic
+B<Simplified Chinese:> Song, Song-Bold, Song-Italic, Song-BoldItalic
 
-* Japanese (Gothic): KozGo KozGo-Bold KozGo-Italic KozGo-BoldItalic
+=item * 
+
+B<Korean:> MyungJo, MyungJo-Bold, MyungJo-Italic, MyungJo-BoldItalic
+
+=item * 
+
+B<Japanese (Mincho):> KozMin, KozMin-Bold, KozMin-Italic, KozMin-BoldItalic
+
+=item * 
+
+B<Japanese (Gothic):> KozGo, KozGo-Bold, KozGo-Italic, KozGo-BoldItalic
 
 =back
 
-Defined Options:
+Defined Options (%opts):
 
-    encode ... specify fonts encoding for non-utf8 text.
+=over
+
+=item encode
+
+specify fonts encoding for non-utf8 text.
+
+=back
 
 =cut
 
@@ -177,6 +202,18 @@ sub tounicodemap {
     return $self;
 }
 
+=head2 glyphByCId
+
+    $n = $font->glyphByCId($gid)
+
+=over
+
+Returns a character's glyph name (string), given its glyph ID.
+
+=back
+
+=cut
+
 sub glyphByCId {
     my ($self, $cid) = @_;
 
@@ -319,8 +356,4 @@ BEGIN {
 
 }
 
-=back
-
-=cut
-
 1;
